@@ -2,31 +2,16 @@
     Personalize recommendations manager module
 """
 import json
-import boto3
 import sdc_helpers.utils as utils
-from sdc_helpers.query_helper import QueryHelper
-from sdc_helpers.redis_helper import RedisHelper
-import sdc_engine_helpers.helpers as helpers
+from sdc_helpers.models.client import Client
+import boto3
+from sdc_engine_helpers.personalize.manager import Manager
 
-class RecommendationsManager:
+
+class RecommendationsManager(Manager):
     """
         Manages retrieval of Personalize recommendations for a given set of parameters
     """
-    service = None
-    query_helper = None
-    redis_helper = None
-    parameters = None
-
-    def __init__(self, **kwargs):
-        self.query_helper = QueryHelper()
-        self.redis_helper = RedisHelper()
-        self.service = self.query_helper.get_service(slug='recommend')
-        self.parameters = kwargs
-
-    def __del__(self):
-        del self.query_helper
-        del self.redis_helper
-
     def get_recommendations(self):
         """
             Get the recommendations for the specified parameters
@@ -42,14 +27,23 @@ class RecommendationsManager:
             raise Exception('ClientError: `itemId` is required')
 
         cache_key = 'recommend-{client_id}-{item_id}'.format(
-            client_id=client['id'],
+            client_id=client.id,
             item_id=item_id
         )
 
         results = self.redis_helper.redis_get(key=cache_key)
 
         if not results:
-            campaign = self.get_campaign(client)
+            campaign_kwargs = {
+                'recipe': self.parameters.get('recipe', 'related_items'),
+                'event_type': self.parameters.get('eventType', 'all')
+            }
+            campaign = self.query_helper.get_campaign(
+                client_id=client.id,
+                service_id=self.service.id,
+                engine_slug=self.engine_slug,
+                **campaign_kwargs
+            )
 
             if not campaign:
                 raise Exception('ServerError: Could not determine campaign for this client')
@@ -83,7 +77,7 @@ class RecommendationsManager:
 
         trigger_log = {
             'trigger': {
-                'client': client['name'],
+                'client': client.name,
                 'type': 'recommendations',
                 'data': {
                     'domain': domain,
@@ -98,69 +92,12 @@ class RecommendationsManager:
 
         return results
 
-    def get_client(self) -> dict:
-        """
-            Determine the client with the supplied parameters
-
-            returns:
-                client (dict): The determined client
-
-        """
-        client = None
-
-        client_id = self.parameters.get('client_id', None)
-        if client_id is not None:
-            client = self.query_helper.get_client(client_id=client_id)
-
-        api_key_id = self.parameters.get('api_key_id', None)
-        if api_key_id is not None:
-            client = self.query_helper.get_client(api_key_id=api_key_id)
-
-        if client is None:
-            raise Exception('ClientError: Could not determine client for this request')
-
-        return client
-
-    def get_campaign(self, client: dict):
-        """
-            Determine the campaign with the supplied parameters
-
-            args:
-                client (dict): The determined client
-
-            returns:
-                campaign (dict): Campaign from the database if found
-
-        """
-        recipe = self.parameters.get('recipe', 'related_items')
-        event_type = self.parameters.get('eventType', 'all')
-
-        subscription_properties = self.query_helper.get_subscription_properties(
-            client_id=client['id'],
-            service_id=self.service['id']
-        )
-
-        if subscription_properties is not None:
-            engine = helpers.get_engine(
-                properties=subscription_properties,
-                slug='personalize'
-            )
-
-            if engine is not None:
-                return helpers.get_campaign(
-                    engine=engine,
-                    recipe=recipe,
-                    event_type=event_type
-                )
-
-        return None
-
-    def get_results(self, *, client: dict, campaign_arn: str, default_results: list) -> list:
+    def get_results(self, *, client: Client, campaign_arn: str, default_results: list) -> list:
         """
             Determine the results for this request
 
             args:
-                client (object): The client requesting the recommendation
+                client (Client): The client requesting the recommendation
                 campaign_arn (str): The AWS Personalize campaign ARN
                 default_results (list): The campaign's default results. If the recommendations
                                         are similar to the default results, an empty results
@@ -203,7 +140,7 @@ class RecommendationsManager:
                 print(
                     'Results for {client_name} are similar but not the same to the default results '
                     'which probably means default results are out of sync. Saving default results'
-                    .format(client_name=client['name'])
+                    .format(client_name=client.name)
                 )
 
             results = []
