@@ -2,9 +2,10 @@
     Sagemaker recommendations manager module
 """
 import json
-import boto3
 import sdc_helpers.utils as utils
+from sdc_helpers.models.client import Client
 from sdc_helpers.redis_helper import RedisHelper
+import boto3
 from sdc_engine_helpers.sagemaker.sagemaker_query_helpers import \
     SagemakerEngineHelpers
 
@@ -37,7 +38,8 @@ class RecommendationsManager:
         # instantiate query helpers
         self.query_helper = SagemakerEngineHelpers(
             rds_config=rds_config,
-            redis_config=redis_config)
+            redis_config=redis_config
+        )
 
         self.redis_helper = RedisHelper(**redis_config)
         # service slug is the same for all engines
@@ -58,11 +60,14 @@ class RecommendationsManager:
         del self.redis_helper
 
     def get_recommendations(
-        self, *,
-        client_id: str,
-        item_id: str, \
-        engine: str,
-        context: dict = {}, **kwargs):
+            self,
+            *,
+            client_id: id,
+            item_id: str,
+            engine: str,
+            context: dict = {},
+            **kwargs
+    ):
         """
             Get the recommendations for the specified parameters
 
@@ -71,22 +76,19 @@ class RecommendationsManager:
             returns:
                 results (dict): Results from the Sagemaker invocation
         """
-        # get client metadata from client_id
         self.client = self.get_client(client_id=client_id)
         self.engine = engine
         # recipe is set by client config
         recipe = kwargs.get('recipe', 'related_items')
 
         campaign = self.get_campaign(
-            client_id=self.client['id'],
+            client_id=self.client.id,
             engine=self.engine,
-            recipe=recipe)
+            recipe=recipe
+        )
 
         if not campaign:
-            raise Exception(
-                            ('ServerError: Could not determine'
-                            ' campaign for this client')
-                        )
+            raise Exception('ServerError: Could not determine campaign for this client')
 
         # changed campaign_arn to be campaign_name
         endpoint_name = campaign['arn']
@@ -94,68 +96,73 @@ class RecommendationsManager:
         results = self.get_results(
             item_id=item_id,
             endpoint_name=endpoint_name,
-            num_results=10)
+            num_results=10
+        )
 
         domain = utils.dict_query(
             dictionary=context,
-            path='domain')
+            path='domain'
+        )
 
         session_hash = utils.dict_query(
             dictionary=context,
-            path='sessionHash')
+            path='sessionHash'
+        )
 
         # trigger will be written with alphabetical order in mind
         trigger_log = {
-                'trigger': {
-                        'client': self.client['name'],
-                        'type': 'recommendations',
-                        'data': {
-                            'domain': domain,
-                            'item_id': item_id,
-                            'session_hash': session_hash,
-                            'results': results
-                            }
-                        }
-                    }
+            'trigger': {
+                'client': self.client.name,
+                'type': 'recommendations',
+                'data': {
+                    'domain': domain,
+                    'item_id': item_id,
+                    'session_hash': session_hash,
+                    'results': results
+                }
+            }
+        }
 
         # write to lambda output logs
         print(json.dumps(trigger_log))
         return results
 
     def get_client(
-        self, *,
-        client_id: str = None,
-        api_key_id: str = None) -> dict:
+            self, *,
+            client_id: int = None,
+            api_key_id: str = None
+    ) -> Client:
         """
             Determine the client with the supplied parameters
+
             Expects either client_id or api_key_id
             args:
                 client_id (int): client id to fetch
                 api_key_id (int): api_key_id to fetch client_id
+
             returns:
-                client (dict): The determined client
+                client (Client): The determined client
 
         """
-        # Possible double retrieve
-        # this is potentially costly
+        client = None
+
         if client_id is not None:
-            # do this first if client_id no None
             client = self.query_helper.get_client(client_id=client_id)
-        elif api_key_id is not None:
-            # do this if client_id==None
-            client = self.query_helper.get_client(api_key_id=api_key_id)
+        else:
+            if api_key_id is not None:
+                client = self.query_helper.get_client(api_key_id=api_key_id)
+
         if client is None:
-            raise Exception(
-                    ('ClientError: Could not determine '
-                    'client for this request')
-                    )
+            raise Exception('ClientError: Could not determine client for this request')
+
         return client
 
     def get_campaign(
-        self, *,
-        client_id: str,
-        engine: str,
-        recipe='related_items') -> dict:
+            self, *,
+            client_id: int,
+            engine: str,
+            recipe='related_items'
+    ) -> dict:
         """
             Determine the campaign with the supplied parameters
             note:
@@ -167,20 +174,24 @@ class RecommendationsManager:
                 recipe (str): recipe name
 
             returns:
-                results (dict): Campaign from the database
+                campaign (dict): Campaign from the database
 
         """
-        campaign = self.query_helper.get_campaign(
-            client_id=client_id,
-            engine=engine,
-            recipe=recipe)
+        campaign_kwargs = {'recipe': recipe}
 
-        return campaign
+        return self.query_helper.get_campaign(
+            client_id=client_id,
+            service_id=self.service.id,
+            engine_slug=engine,
+            **campaign_kwargs
+        )
 
     def encode_item_code(
-        self, *,
-        item_ids: list,
-        from_cache: bool = True):
+            self,
+            *,
+            item_ids: list,
+            from_cache: bool = True
+    ):
         """
             Lookup a list of item codes
 
@@ -194,15 +205,17 @@ class RecommendationsManager:
         item_codes = []
 
         cache_key = self.query_helper.build_cache_key(
-            service=self.service['name'],
+            service=self.service.name,
             obj_group=self.item_code_identifier,
-            prefix=[self.engine, self.client['name']])
+            prefix=[self.engine, self.client.name]
+        )
 
         if from_cache:
             # encode item_id -> item_code
             item_codes = self.redis_helper.redis_hmget(
                 hashkey=cache_key,
-                keys=item_ids)
+                keys=item_ids
+            )
 
         for i, item_code in enumerate(item_codes):
             # decode item_ids bytes -> str
@@ -214,22 +227,27 @@ class RecommendationsManager:
                 # get item_id from database if none
                 key = item_ids[i]
                 item_code = self.query_helper.get_item_from_lookup(
-                    client_id=self.client['id'],
+                    client_id=self.client.id,
+                    service_id=self.service.id,
                     engine=self.engine,
                     label=self.item_code_identifier,
-                    key=key)
+                    key=key
+                )
 
                 if item_code is not None:
                     # store in cache
                     self.redis_helper.redis_hmset(hashkey=cache_key, dict_obj={key:item_code})
 
             item_codes[i] = item_code
+
         return item_codes
 
     def decode_item_code(
-        self, *,
-        item_codes: list,
-        from_cache: bool = True):
+            self,
+            *,
+            item_codes: list,
+            from_cache: bool = True
+    ):
         """"
             Lookup a list of item codes
 
@@ -242,16 +260,18 @@ class RecommendationsManager:
         item_ids = []
 
         cache_key = self.query_helper.build_cache_key(
-            service=self.service['name'],
+            service=self.service.name,
             obj_group=self.item_id_identifier,
-            prefix=[self.engine, self.client['name']])
+            prefix=[self.engine, self.client.name]
+        )
 
         if from_cache:
             # decode item_codes -> item_ids
             item_ids = self.redis_helper.redis_hmget(
                 hashkey=cache_key,
-                keys=item_codes)
-            
+                keys=item_codes
+            )
+
         for i, item_id in enumerate(item_ids):
             if isinstance(item_id, bytes):
                 # decode item_ids bytes -> str
@@ -262,10 +282,12 @@ class RecommendationsManager:
                 # get item_id from database if none
                 key = item_codes[i]
                 item_id = self.query_helper.get_item_from_lookup(
-                    client_id=self.client['id'],
+                    client_id=self.client.id,
+                    service_id=self.service.id,
                     engine=self.engine,
                     label=self.item_id_identifier,
-                    key=key)
+                    key=key
+                )
 
                 if item_id is not None:
                     # store in cache
@@ -276,10 +298,12 @@ class RecommendationsManager:
         return item_ids
 
     def get_results(
-        self, *,
-        item_id: str,
-        endpoint_name: str,
-        num_results: int = 10) -> list:
+            self,
+            *,
+            item_id: str,
+            endpoint_name: str,
+            num_results: int = 10
+    ) -> list:
         """
             Determine the results for this request
 
@@ -303,16 +327,19 @@ class RecommendationsManager:
             # make the recommender ignore self recommendation
             event = {
                 'item_code':int(item_code[0]),
-                'args':{
+                'args': {
                     'n_similar':num_results,
-                    'exclude':[int(item_code[0])]}}
+                    'exclude':[int(item_code[0])]
+                }
+            }
             payload = json.dumps(event)
 
             # get recommendations
             response = sagemaker_runtime.invoke_endpoint(
                 EndpointName=endpoint_name,
                 ContentType='application/json',
-                Body=payload)
+                Body=payload
+            )
 
             # decode application/json response
             response_decoded = json.loads(response['Body'].read().decode())
@@ -329,9 +356,6 @@ class RecommendationsManager:
         results = self.decode_item_code(item_codes=recommendations)
         # check list of item_ids are not all None
         if all(item_id is None for item_id in results):
-            raise Exception(
-                            ('ClientError: Unable to decode'
-                            ' recommendations to item_id')
-                        )
+            raise Exception('ClientError: Unable to decode recommendations to item_id')
 
         return results
